@@ -2,21 +2,23 @@
 jgtutils package
 """
 
-__version__ = "0.1.69"
+version='0.2.57'
 
+import sys
+import os
 
-from jgtutils import jgtpov as pov
-
-from jgtutils.jgtpov import calculate_tlid_range as get_tlid_range
-
-from jgtutils import jgtos as jos
-
-from jgtos import tlid_range_to_start_end_datetime, tlid_range_to_jgtfxcon_start_end_str
-
-from jgtutils import jgtwslhelper as wsl
+sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
 
+from jgtos import (tlid_range_to_jgtfxcon_start_end_str,
+                   tlid_range_to_start_end_datetime)
 
 from jgtutils import jgtcommon as common
+from jgtutils import jgtos as jos
+from jgtutils import jgtpov as pov
+from jgtutils import jgtwslhelper as wsl
 from jgtutils.jgtcommon import readconfig
+from jgtutils.jgtpov import calculate_tlid_range as get_tlid_range
 
-from jgtutils import jgtlogging as jlog
+
+def load_logging():
+  from jgtutils import jgtlogging as jlog
